@@ -7,7 +7,7 @@
 #  define KMM_PLUGIN_NO_EXPORT
 #else
 #  ifndef KMM_PLUGIN_EXPORT
-#    ifdef MAKE_KMM_PLUGIN_LIB
+#    ifdef kmm_plugin_EXPORTS
         /* We are building this library */
 #      define KMM_PLUGIN_EXPORT __attribute__((visibility("default")))
 #    else
@@ -33,9 +33,10 @@
 #  define KMM_PLUGIN_DEPRECATED_NO_EXPORT KMM_PLUGIN_NO_EXPORT KMM_PLUGIN_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KMM_PLUGIN_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KMM_PLUGIN_NO_DEPRECATED
+#    define KMM_PLUGIN_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
